﻿using Kivii;
using Kivii.Finances.Entities;
using Kivii.Linq;
using Kivii.Organizations.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Njzj.Ngstc
{
    public static class Extension
    {
        private static Dictionary<string, Organization> _orgs = new Dictionary<string, Organization>();

        public static List<NgstcDetail> GetNgstcDetails(this string ngstcNumber)
        {
            var client = new JsonHttpClient(Configs.baseUrl);
            var route = $"{Configs.routeNgstcDetail}?sn={Configs.orgCode}&tn={ngstcNumber}&qn={Configs.signature}";
            var rtns = client.Get<NgstcResponse>(route);
            if (rtns.code != 0) throw new Exception(rtns.msg);
            return rtns.SFBillInfos;
        }

        public static List<SettlementDetail> ConvertToSettlementDetail(this List<NgstcDetail> ngstcDetails)
        {
            var rtns = new List<SettlementDetail>();
            foreach (var item in ngstcDetails)
            {
                var detail = new SettlementDetail();
                detail.GoodsFullName = item.BatchNo;
                detail.GoodsId = item.Region;
                detail.GoodsSpecifications = item.BillType;
                detail.GoodsModel = item.Source;
                detail.BizId = item.CShortName;
                detail.BizType = item.CName;
                detail.Remark = item.TabDate;
                detail.QuantityUnitPrice = item.AmountComplete;
                detail.QuantityUnitPricePlan = item.Amount;
                detail.Quantity = item.Weight;
                detail.Amount = item.CurPrice;
                detail.AmountPlan = item.OriPrice;
                rtns.Add(detail);
            }

            return rtns;
        }

        public static string UpdateNgstcBill(this NgstcUpdate ngstcUpdate)
        {
            var client = new JsonHttpClient(Configs.baseUrl);
            var route = $"{Configs.routeNgstcUpdate}?sn={Configs.orgCode}&BillNo={ngstcUpdate.BillNo}&UnPaid={ngstcUpdate.UnPaid}&Paid={ngstcUpdate.Paid}&BillState={ngstcUpdate.BillState}&PayDate={ngstcUpdate.PayDate}&Remark={ngstcUpdate.Remark}&qn={Configs.signature}";
            var rtns = client.Get<NgstcResponse>(route);
            if (rtns.code != 0) throw new Exception(rtns.msg);
            return rtns.msg;
        }

        public static Organization GetOrganization(this string internalCode)
        {
            internalCode.ThrowIfNullOrEmpty("请传入部门内部编码!");
            internalCode = internalCode.ToLower();
            if (_orgs.ContainsKey(internalCode))
            {
                return _orgs[internalCode];
            }
            var conn = KiviiContext.GetOpenedDbConnection<Organization>();
            var orgs = conn.Select<Organization>();
            foreach (var item in orgs)
            {
                if (item.InternalCode.IsNullOrEmpty()) continue;
                var code = item.InternalCode.ToLower();
                _orgs[code] = item;
            }
            if (_orgs.ContainsKey(internalCode))
            {
                return _orgs[internalCode];
            }
            return null;


        }
    }
}
